kooplearn package
=================

Submodules
----------

.. toctree::
   :maxdepth: 4

   kooplearn.estimators
   kooplearn.kernels
   kooplearn.utils

Module contents
---------------

.. automodule:: kooplearn
   :members:
   :undoc-members:
   :show-inheritance:
